@@ -1,31 +1,20 @@
-/********************************************************************
-Copyright 2015  Martin Gräßlin <mgraesslin@kde.org>
-Copyright 2015  Marco Martin <mart@kde.org>
+/*
+    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>
+    SPDX-FileCopyrightText: 2015 Marco Martin <mart@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef KWAYLAND_CONTRAST_H
 #define KWAYLAND_CONTRAST_H
 
+#include <optional>
+
 #include <QObject>
 #include <QPoint>
 #include <QSize>
+#include <QColor>
 
-#include <KWayland/Client/kwaylandclient_export.h>
+#include "KWayland/Client/kwaylandclient_export.h"
 
 struct org_kde_kwin_contrast;
 struct org_kde_kwin_contrast_manager;
@@ -34,7 +23,6 @@ namespace KWayland
 {
 namespace Client
 {
-
 class EventQueue;
 class Contrast;
 class Surface;
@@ -54,7 +42,7 @@ public:
      * Registry::createContrastManager.
      **/
     explicit ContrastManager(QObject *parent = nullptr);
-    virtual ~ContrastManager();
+    ~ContrastManager() override;
 
     /**
      * @returns @c true if managing a org_kde_kwin_contrast_manager.
@@ -107,8 +95,8 @@ public:
     Contrast *createContrast(Surface *surface, QObject *parent = nullptr);
     void removeContrast(Surface *surface);
 
-    operator org_kde_kwin_contrast_manager*();
-    operator org_kde_kwin_contrast_manager*() const;
+    operator org_kde_kwin_contrast_manager *();
+    operator org_kde_kwin_contrast_manager *() const;
 
 Q_SIGNALS:
     /**
@@ -143,7 +131,7 @@ class KWAYLANDCLIENT_EXPORT Contrast : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~Contrast();
+    ~Contrast() override;
 
     /**
      * Setup this Contrast to manage the @p contrast.
@@ -166,10 +154,8 @@ public:
      * that the instance can be deleted or set up to a new org_kde_kwin_contrast interface
      * once there is a new connection available.
      *
-     * It is suggested to connect this method to ConnectionThread::connectionDied:
-     * @code
-     * connect(connection, &ConnectionThread::connectionDied, contrast, &Contrast::destroy);
-     * @endcode
+     * This method is automatically invoked when the Registry which created this
+     * Contrast gets destroyed.
      *
      * @see release
      **/
@@ -182,7 +168,7 @@ public:
     void commit();
 
     /**
-     * Sets the area of the window that will have a contrastred
+     * Sets the area of the window that will have a contrasted
      * background.
      * The region will have to be created with
      * Compositor::createRegion(QRegion)
@@ -192,8 +178,10 @@ public:
     void setIntensity(qreal intensity);
     void setSaturation(qreal saturation);
 
-    operator org_kde_kwin_contrast*();
-    operator org_kde_kwin_contrast*() const;
+    void setFrost(QColor frost);
+
+    operator org_kde_kwin_contrast *();
+    operator org_kde_kwin_contrast *() const;
 
 private:
     friend class ContrastManager;
@@ -206,4 +194,3 @@ private:
 }
 
 #endif
-
